matminer.featurizers.utils.tests package — matminer 0.5.1 documentation

# matminer.featurizers.utils.tests package

## Submodules

## matminer.featurizers.utils.tests.test_cgcnn module

class `matminer.featurizers.utils.tests.test_cgcnn.` `TestCGCNNWrappers`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_appropriate_kwargs`()
  `test_atom_custom_array_initializer`()
  `test_cifdatawrapper`()
  `test_crystal_graph_convnet_wrapper`()
  `test_get_cgcnn_data`()

## matminer.featurizers.utils.tests.test_grdf module

class `matminer.featurizers.utils.tests.test_grdf.` `GRDFTests`(methodName='runTest')

  Bases: `pymatgen.util.testing.PymatgenTest`

  `test_bessel`()
  `test_cosine`()
  `test_gaussian`()
  `test_histogram`()
  `test_load_class`()
  `test_sin`()

## matminer.featurizers.utils.tests.test_stats module

class `matminer.featurizers.utils.tests.test_stats.` `TestPropertyStats`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  `setUp`()

    Hook method for setting up the test fixture before exercising it.

  `test_avg_dev`()
  `test_geom_std_dev`()
  `test_holder_mean`()
  `test_kurtosis`()
  `test_maximum`()
  `test_mean`()
  `test_minimum`()
  `test_mode`()
  `test_quantile`()
  `test_range`()
  `test_skewness`()
  `test_std_dev`()

## Module contents